@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Generic, TypeVar
+from typing import Any, Generic, TypeVar
 from lightkit.nn._protocols import ConfigurableModule
 from lightkit.utils import get_generic_type
 from .base import BaseEstimator
@@ -14,18 +14,7 @@ class ConfigurableBaseEstimator(BaseEstimator, Generic[M]):
     :class:`lightkit.nn.Configurable` mixin.
     """
 
-    @property
-    def model_(self) -> M:
-        """
-        The fitted PyTorch module containing all estimated parameters.
-        """
-        if not hasattr(self, "_model"):
-            raise NotFittedError(f"`{self.__class__.__name__}` has not been fitted yet")
-        return self._model
-
-    @model_.setter
-    def model_(self, model: M) -> None:
-        self._model = model
+    model_: M
 
     def save_attributes(self, path: Path) -> None:
         # First, store simple attributes
@@ -41,3 +30,11 @@ class ConfigurableBaseEstimator(BaseEstimator, Generic[M]):
         # Then, load the model
         model_cls = get_generic_type(self.__class__, ConfigurableBaseEstimator)
         self.model_ = model_cls.load(path / "model")  # type: ignore
+
+    def __getattr__(self, key: str) -> Any:
+        try:
+            return super().__getattr__(key)
+        except AttributeError as e:
+            if key.endswith("_") and not key.endswith("__") and not key.startswith("_"):
+                raise NotFittedError(f"`{self.__class__.__name__}` has not been fitted yet") from e
+            raise e
